@@ -5,12 +5,16 @@ use anchor_lang::prelude::*;
 
 /// Wrapper module.
 pub mod fee_to {
-    solana_program::declare_id!("4MMZH3ih1aSty2nx4MC3kSR94Zb55XsXnqb5jfEcyHWQ");
+    use anchor_lang::declare_id;
+
+    declare_id!("4MMZH3ih1aSty2nx4MC3kSR94Zb55XsXnqb5jfEcyHWQ");
 }
 
 /// Wrapper module.
 pub mod fee_setter {
-    solana_program::declare_id!("4MMZH3ih1aSty2nx4MC3kSR94Zb55XsXnqb5jfEcyHWQ");
+    use anchor_lang::declare_id;
+
+    declare_id!("4MMZH3ih1aSty2nx4MC3kSR94Zb55XsXnqb5jfEcyHWQ");
 }
 
 /// Account authorized to take fees.
